{# -*- coding: utf-8 -*-

  This file is part of Invenio.
  Copyright (C) 2016-2018 CERN.

  Invenio is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}

{%- block header -%}
    {%- if logo -%}
        <img src="{{ logo }}" />
    {%- endif -%}
{%- endblock header -%}

{%- block body -%}
    {%- block greetings -%}
        <p>Dear {{ user }},</p>
    {%- endblock greetings -%}

    {%- block content -%}
        <p>{{ content }}</p>
    {%- endblock content -%}

    {%- block regards -%}
        <p>Regards,</p>
        <p>{{ sender }}</p>
    {%- endblock regards -%}
{%- endblock body -%}
